@@ -1,10 +1,11 @@
+#' @import graphics
 #' @import rngtools
 #' @import digest
 #' @import stringr
 #' @import stats
+#' @import methods
 NULL
-library(digest)
-library(pkgmaker)
+#library(digest)
 
 #' Defunct Functions and Classes in the NMF Package
 #' 
@@ -69,20 +70,21 @@ devnmf <- function(){
 nmfConfig <- mkoptions()
 
 .onLoad <- function(libname, pkgname) {
-	
-	pkgEnv <- pkgmaker::packageEnv()
 		
 	# set default number of cores
 	if( pkgmaker::isCHECK() ){
 		options(cores=2)
 	}else{
-		if( nchar(nc <- Sys.getenv('_R_NMF_CORES_')) > 0 ){
+		if( nchar(nc <- Sys.getenv('R_PACKAGE_NMF_CORES')) > 0 ){
 			try({
 				nmf.options(cores=as.numeric(nc))
 			})
-		}
+		}   
 	}
-	
+    # use grid patch?
+    nmf.options(grid.patch = !isFALSE(Sys.getenv_value('R_PACKAGE_NMF_GRID_PATCH')))
+    
+    pkgEnv <- pkgmaker::packageEnv()
 	.init.sequence <- function(){
 	
 		## 0. INITIALIZE PACKAGE SPECFIC OPTIONS
@@ -118,7 +120,6 @@ nmfConfig <- mkoptions()
 
 .onUnload <- function(libpath) {
 	
-	# TODO: pkgmaker::onUnload(libpath)
 	# unload compiled library
 	dlls <- names(base::getLoadedDLLs())
 	if ( 'NMF' %in%  dlls )
